@@ -1,5 +1,7 @@
 import pytest
-from solid_backend.quiz.models import QuizQuestion, QuizAnswer
+
+from solid_backend.photograph.models import Photograph
+from solid_backend.quiz.models import QuizAnswer, QuizQuestion
 
 
 @pytest.fixture
@@ -10,3 +12,8 @@ def quiz_question_model_class():
 @pytest.fixture
 def quiz_answer_model_class():
     return QuizAnswer
+
+
+@pytest.fixture
+def photograph_model_class():
+    return Photograph
